@@ -65,16 +65,23 @@ BEGIN {
 		my $nextlevel = ($msg =~ /^.* at (\S+) line (\d+)(?:, *<[^>]*> line \d+)?\.?\n/)
 			? Sys::Syslog::LOG_DEBUG
 			: $level;
-
+		my $terminal = -t STDERR;
+		STDERR->autoflush(0) if $terminal;
+		my $time = strftime('%Y-%m-%d %H:%M:%S', localtime);
 		foreach my $line (split("\n", $msg)) {
 			$line =~ s/\s+$//;
 			next unless $line;
+			print STDERR "[$time] [$logname] $pfx$line\n" if $terminal;
 			$line =~ s/\t/    /g;
 			$line = $pfx.$line;
 			utf8::encode($line);
 			syslog($level, '%s', $line);
 			$level = $nextlevel;
 		}
+		if($terminal) {
+			STDERR->flush;
+			STDERR->autoflush(1);
+		}
 	}
 
 	log_set_name($logname);
@@ -422,17 +429,3 @@ if($err) {
 	warn $err;
 	exit(1);
 }
-
-__END__
-
-=encoding utf8
-
-=head1 NAME
-
-xyzzy - process manager for Xyzzy applications
-
-=head1 SYNOPSIS
-
- xyzzy /path/to/app.cfg
-
-=cut
