@@ -6,8 +6,8 @@ package Xyzzy::CAS::Request;
 
 use Xyzzy::Util qw(uri_escape_auto);
 use Xyzzy::CAS::Session;
+use LWP;
 use URI;
-BEGIN { eval "use WWW::Curl::Easy" }
 
 use Xyzzy::Request -self;
 
@@ -34,32 +34,10 @@ sub build_url() {
 
 sub fetch_url {
 	my $url = build_url(@_);
-	my $cfg = $self->cfg;
-
-	if($cfg->cas_use_curl) {
-		my $curl = $cfg->cas_curl;
-		$curl->setopt(CURLOPT_URL(), $url);
-		$curl->setopt(CURLOPT_WRITEDATA(), \my $body);
-
-		my $ret = $curl->perform;
-		if($ret == 0) {
-			my $code = $curl->getinfo(CURLINFO_HTTP_CODE());
-			die "Unable to fetch '$url': got HTTP status code $code\n"
-				unless $code == 200;
-		} else {
-			my $strerror = $curl->strerror($ret);
-			my $errbuf = $curl->errbuf;
-			die "Unable to fetch '$url': $strerror ($ret): $errbuf\n";
-		}
-
-		return $body;
-	} else {
-		my $ua = $cfg->cas_lwp;
-		my $res = $ua->get($url);
-		die "got ".$res->status_line." while fetching '$url'\n"
-			unless $res->is_success;
-		return $res->decoded_content;
-	}
+	our $ua //= new LWP::UserAgent;
+	my $res = $ua->get($url);
+	die "got ".$res->status_line." while fetching '$url'\n" unless $res->is_success;
+	return $res->decoded_content;
 }
 
 field cas_clean_url => sub {
@@ -73,13 +51,13 @@ field cas_clean_url => sub {
 	my $is_localhost = $url->host =~ /^(?:localhost|127\.0\.0\.1)$/;
 	my $is_hostname = $url->host !~ /\./;
 
-	if(my $domain = $cfg->cas_domain) {
+	if(my $domain = $cfg->domain) {
 		$url->host($domain)
-			if !$is_localhost && ($is_hostname || $cfg->cas_force_domain);
+			if !$is_localhost && ($is_hostname || $cfg->force_domain);
 	}
 	
 	$url->scheme('https')
-		if $url->scheme eq 'http' && $cfg->cas_force_https && !$is_localhost && !$has_port;
+		if $url->scheme eq 'http' && $cfg->force_https && !$is_localhost && !$has_port;
 
 	# remove ticket=... from the query part
 	my $query = $url->query;
@@ -128,13 +106,9 @@ field cur_session => sub {
 
 sub cas_redirect {
 	my $url = shift;
-	# The client must not be tempted to direct POST/PUT/DELETE/etc
-	# requests at the CAS server.
-	my $code = $self->request_method =~ /^(?:GET|HEAD)$/a ? 302 : 403;
-	my $status = new Xyzzy::Status($code);
+	my $status = new Xyzzy::Status(302);
 	my $res = $status->response;
-	$res->addheader(Location => $url)
-		if $code == 302;
+	$res->addheader(Location => $url);
 	die $res;
 }
 
@@ -142,7 +116,7 @@ sub valid_ticket {
 	my $ticket = $self->ticket;
 	return undef unless defined $ticket;
 	my $url = $self->cas_clean_url;
-	my $res = $self->fetch_url($self->cfg->cas_validate_url, ticket => $ticket, service => $url);
+	my $res = $self->fetch_url($self->cfg->validate_url, ticket => $ticket, service => $url);
 	return undef unless $res =~ /^yes\n([A-Za-z0-9_-]+)\n$/;
 	return $1;
 }
@@ -151,7 +125,7 @@ sub login {
 	my $uid = $self->session // $self->valid_ticket;
 	return $uid if defined $uid;
 	my $url = $self->cas_clean_url;
-	$self->cas_redirect(build_url($self->cfg->cas_login_url, service => $url));
+	$self->cas_redirect(build_url($self->cfg->login_url, service => $url));
 }
 
 param nonce => sub {
